[llvm] r218593 - Remove dead code from DIBuilder

Jyoti Allur jyoti.allur at samsung.com
Sun Sep 28 23:32:54 PDT 2014


Author: jyoti.allur
Date: Mon Sep 29 01:32:54 2014
New Revision: 218593

URL: http://llvm.org/viewvc/llvm-project?rev=218593&view=rev
Log:
Remove dead code from DIBuilder

Modified:
    llvm/trunk/include/llvm/IR/DIBuilder.h
    llvm/trunk/lib/IR/DIBuilder.cpp

Modified: llvm/trunk/include/llvm/IR/DIBuilder.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/IR/DIBuilder.h?rev=218593&r1=218592&r2=218593&view=diff
==============================================================================
--- llvm/trunk/include/llvm/IR/DIBuilder.h (original)
+++ llvm/trunk/include/llvm/IR/DIBuilder.h Mon Sep 29 01:32:54 2014
@@ -451,33 +451,8 @@ namespace llvm {
     /// implicitly uniques the values returned.
     DISubrange getOrCreateSubrange(int64_t Lo, int64_t Count);
 
-    /// createGlobalVariable - Create a new descriptor for the specified global.
-    /// @param Name        Name of the variable.
-    /// @param File        File where this variable is defined.
-    /// @param LineNo      Line number.
-    /// @param Ty          Variable Type.
-    /// @param isLocalToUnit Boolean flag indicate whether this variable is
-    ///                      externally visible or not.
-    /// @param Val         llvm::Value of the variable.
-    DIGlobalVariable
-    createGlobalVariable(StringRef Name, DIFile File, unsigned LineNo,
-                         DITypeRef Ty, bool isLocalToUnit, llvm::Value *Val);
-
-    /// \brief Create a new descriptor for the specified global.
-    /// @param Name        Name of the variable.
-    /// @param LinkageName Mangled variable name.
-    /// @param File        File where this variable is defined.
-    /// @param LineNo      Line number.
-    /// @param Ty          Variable Type.
-    /// @param isLocalToUnit Boolean flag indicate whether this variable is
-    ///                      externally visible or not.
-    /// @param Val         llvm::Value of the variable.
-    DIGlobalVariable
-    createGlobalVariable(StringRef Name, StringRef LinkageName, DIFile File,
-                         unsigned LineNo, DITypeRef Ty, bool isLocalToUnit,
-                         llvm::Value *Val);
 
-    /// createStaticVariable - Create a new descriptor for the specified
+    /// createGlobalVariable - Create a new descriptor for the specified
     /// variable.
     /// @param Context     Variable scope.
     /// @param Name        Name of the variable.
@@ -490,15 +465,15 @@ namespace llvm {
     /// @param Val         llvm::Value of the variable.
     /// @param Decl        Reference to the corresponding declaration.
     DIGlobalVariable
-    createStaticVariable(DIDescriptor Context, StringRef Name,
+    createGlobalVariable(DIDescriptor Context, StringRef Name,
                          StringRef LinkageName, DIFile File, unsigned LineNo,
                          DITypeRef Ty, bool isLocalToUnit, llvm::Value *Val,
                          MDNode *Decl = nullptr);
 
     /// createTempStaticVariableFwdDecl - Identical to createStaticVariable
     /// except that the resulting DbgNode is temporary and meant to be RAUWed.
     DIGlobalVariable
-    createTempStaticVariableFwdDecl(DIDescriptor Context, StringRef Name,
+    createTempGlobalVariableFwdDecl(DIDescriptor Context, StringRef Name,
                                     StringRef LinkageName, DIFile File,
                                     unsigned LineNo, DITypeRef Ty,
                                     bool isLocalToUnit, llvm::Value *Val,
@@ -490,15 +465,15 @@ namespace llvm {
                          MDNode *Decl = nullptr);
 
-    /// createTempStaticVariableFwdDecl - Identical to createStaticVariable
+    /// createTempGlobalVariableFwdDecl - Identical to createGlobalVariable
     /// except that the resulting DbgNode is temporary and meant to be RAUWed.
     DIGlobalVariable

Modified: llvm/trunk/lib/IR/DIBuilder.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/IR/DIBuilder.cpp?rev=218593&r1=218592&r2=218593&view=diff
==============================================================================
--- llvm/trunk/lib/IR/DIBuilder.cpp (original)
+++ llvm/trunk/lib/IR/DIBuilder.cpp Mon Sep 29 01:32:54 2014
@@ -948,44 +948,8 @@ DISubrange DIBuilder::getOrCreateSubrang
   return DISubrange(MDNode::get(VMContext, Elts));
 }
 
-/// \brief Create a new descriptor for the specified global.
-DIGlobalVariable DIBuilder::createGlobalVariable(StringRef Name,
-                                                 StringRef LinkageName,
-                                                 DIFile F, unsigned LineNumber,
-                                                 DITypeRef Ty, bool isLocalToUnit,
-                                                 Value *Val) {
-  Value *Elts[] = {
-    GetTagConstant(VMContext, dwarf::DW_TAG_variable),
-    Constant::getNullValue(Type::getInt32Ty(VMContext)),
-    nullptr, // TheCU,
-    MDString::get(VMContext, Name),
-    MDString::get(VMContext, Name),
-    MDString::get(VMContext, LinkageName),
-    F,
-    ConstantInt::get(Type::getInt32Ty(VMContext), LineNumber),
-    Ty,
-    ConstantInt::get(Type::getInt32Ty(VMContext), isLocalToUnit),
-    ConstantInt::get(Type::getInt32Ty(VMContext), 1), /* isDefinition*/
-    Val,
-    DIDescriptor()
-  };
-  MDNode *Node = MDNode::get(VMContext, Elts);
-  AllGVs.push_back(Node);
-  return DIGlobalVariable(Node);
-}
-
-/// \brief Create a new descriptor for the specified global.
-DIGlobalVariable DIBuilder::createGlobalVariable(StringRef Name, DIFile F,
-                                                 unsigned LineNumber,
-                                                 DITypeRef Ty,
-                                                 bool isLocalToUnit,
-                                                 Value *Val) {
-  return createGlobalVariable(Name, Name, F, LineNumber, Ty, isLocalToUnit,
-                              Val);
-}
-
 static DIGlobalVariable
-createStaticVariableHelper(LLVMContext &VMContext, DIDescriptor Context,
+createGlobalVariableHelper(LLVMContext &VMContext, DIDescriptor Context,
                            StringRef Name, StringRef LinkageName, DIFile F,
                            unsigned LineNumber, DITypeRef Ty, bool isLocalToUnit,
                            Value *Val, MDNode *Decl, bool isDefinition,
@@ -1009,16 +973,16 @@ createStaticVariableHelper(LLVMContext &
   return DIGlobalVariable(CreateFunc(Elts));
 }
 
-/// createStaticVariable - Create a new descriptor for the specified
+/// createGlobalVariable - Create a new descriptor for the specified
 /// variable.
-DIGlobalVariable DIBuilder::createStaticVariable(DIDescriptor Context,
+DIGlobalVariable DIBuilder::createGlobalVariable(DIDescriptor Context,
                                                  StringRef Name,
                                                  StringRef LinkageName,
                                                  DIFile F, unsigned LineNumber,
                                                  DITypeRef Ty,
                                                  bool isLocalToUnit,
                                                  Value *Val, MDNode *Decl) {
-  return createStaticVariableHelper(VMContext, Context, Name, LinkageName, F,
+  return createGlobalVariableHelper(VMContext, Context, Name, LinkageName, F,
                                     LineNumber, Ty, isLocalToUnit, Val, Decl, true,
                                     [&] (ArrayRef<Value *> Elts) -> MDNode * {
                                       MDNode *Node = MDNode::get(VMContext, Elts);
@@ -1027,17 +991,17 @@ DIGlobalVariable DIBuilder::createStatic
                                     });
 }
 
 /// createTempStaticVariableFwdDecl - Create a new temporary descriptor for the
 /// specified variable declarartion.
 DIGlobalVariable
-DIBuilder::createTempStaticVariableFwdDecl(DIDescriptor Context,
+DIBuilder::createTempGlobalVariableFwdDecl(DIDescriptor Context,
                                            StringRef Name,
                                            StringRef LinkageName,
                                            DIFile F, unsigned LineNumber,
                                            DITypeRef Ty,
                                            bool isLocalToUnit,
                                            Value *Val, MDNode *Decl) {
-  return createStaticVariableHelper(VMContext, Context, Name, LinkageName, F,
+  return createGlobalVariableHelper(VMContext, Context, Name, LinkageName, F,
                                     LineNumber, Ty, isLocalToUnit, Val, Decl, false,
                                     [&] (ArrayRef<Value *> Elts) {
                                       return MDNode::getTemporary(VMContext, Elts);
@@ -1027,17 +991,17 @@ DIGlobalVariable DIBuilder::createStatic
 }
 
-/// createTempStaticVariableFwdDecl - Create a new temporary descriptor for the
+/// createTempGlobalVariableFwdDecl - Create a new temporary descriptor for the
 /// specified variable declarartion.
 DIGlobalVariable





More information about the llvm-commits mailing list